set scheme s1color
ssc install freduse

/* This do file constructs the three figures and two tables appearing in 
   "How Accurate Are Long-Run Employment Projections" 
   
   The inputs into this file are:
      1) Data from the Occupational Employment Statistics :
	      oes_00.csv, oes_01.csv, .... oes_19.csv
      2) O*NET 15
	  3) blinder.csv, and frey.csv: Offshorability measure in Blinder (2009) and 
	     probability of automation measure in Frey and Osborne (2017)
	  4) bls_2000_2010_projec.csv
	     bls_2010_2020_projec.csv
		 bls_2019_2029_projec.csv
		 These are BLS decade ahead projections.	 
	  5) Crosswalks: soc_2000_to_2010_crosswalk.csv
					 soc2018_to_soc_corresp.csv
      6) soc-structure-2000.csv 
	  
	 There are nine steps in this do file
	   1) Read in data from the OES
	   2) Construct my version of the Acemoglu and Autor (2011) routineness measure
	   3) Read in Jentsen and Kletzer and Blinder offshorability measures
	   4) Read in BLS projections
	   5) Read in Frey and Osborne automation measure; merge in the datasets from steps 1 -4
	   6) Produce Figure 4B using data from the 2000s
	   7) Produce Figures 4, 5-7, Table 1
	   8) Output the material behind the figures into a csv file. 
	   9) Produce figures 1-3. 
	   
	   There is one set of figures, employment by occupation in the Scheduled
		Air Transportation industry, mentioned in the paper but not discussed 
		in this do file. Those figures can be found directly at
		https://data.bls.gov/projections/nationalMatrix?queryParams=481100&ioType=i
	   
   */

/* 
Step 1: 
These initial datasets from the the BLS Occupational Employment Statistics 
program. We will create two datasets from these:
1) Occupation employment in 2000 and 2010.
2) Occupation employment in 2010 and 2019.
*/

insheet using oes_00.csv, clear
replace occ_group="total" if occ_code=="00-0000"
replace occ_group="detailed" if occ_group==""
save oes_00, replace
insheet using oes_10.csv, clear
replace occ_group="total" if occ_code=="00-0000"
replace occ_group="detailed" if occ_group==""
save oes_10, replace
insheet using oes_19.csv, clear names
save oes_19, replace 
merge 1:1 occ_group occ_code using oes_10
keep if  _merge==3  & occ_group=="detailed"
drop _me*
ren occ_code occsoc
replace occsoc=subinstr(occsoc,"-", "", .)
destring occsoc, replace force
save oes_10_19, replace

use oes_00, replace
merge 1:1 occ_group occ_code using oes_10
keep if  _merge==3  & occ_group=="detailed"
drop _me*
ren occ_code occsoc
replace occsoc=subinstr(occsoc,"-", "", .)
destring occsoc, replace force
save oes_00_10, replace

/* Step 2: Read in data from O*NET 15 to produce the Acemoglu and Autor (2011)
   routineness index. See page 1163 from the paper for the definitions.  Note that 
   unlike Acemoglu and Autor (2011), instead of normalizing each component of the index
   to have mean 0 and standard deviation 1, I transform each variable so that it ranges
   from 0 to 100.
   
   */

   /* Routine cognitive is the average of importance of repeating the same tasks (4C3b7), importance of being exact or accurate (4C3b4), and the (inverse of) structured versus unstructured work */
insheet using "onet_15/Work Context.txt", clear
keep if elementid=="4.C.3.b.7" | elementid=="4.C.3.b.4" | elementid=="4.C.3.b.8"
keep if scaleid=="CX"
replace datav=(datav-1)*25 
replace datav=100-datav if elementid=="4.C.3.b.8"
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_rc
save acemoglu_autor, replace

/* The nonroutine manual is the combination of 
4.A.3.a.4 Operating vehicles, mechanized devices, or equipment
4.C.2.d.1.g Spend time using hands to handle, control or feel objects, tools or controls
1.A.2.a.2 Manual dexterity
1.A.1.f.1 Spatial orientation
*/

insheet using "onet_15/Work Context.txt", clear
keep if elementid=="4.C.2.d.1.g" 
keep if scaleid=="CX"
replace datav=(datav-1)*25/4
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_nrm1
merge 1:1 onetsoc using acemoglu_autor
drop _merge
save acemoglu_autor, replace

insheet using onet_15/Abilities.txt, clear
keep if elementid=="1.A.2.a.2" | elementid=="1.A.1.f.1"
keep if scaleid~="LV"
replace datav=(datav-1)*25/2
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_nrm2
merge 1:1 onetsoc using acemoglu_autor
drop _merge
save acemoglu_autor, replace

insheet using "onet_15/Work Activities.txt", clear
keep if elementid=="4.A.3.a.4" 
keep if scaleid~="LV"
replace datav=(datav-1)*25/4 
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_nrm3
merge 1:1 onetsoc using acemoglu_autor
drop _merge
gen task_nrm=task_nrm3+task_nrm1+task_nrm2
drop task_nrm1 task_nrm2 task_nrm3 
save acemoglu_autor, replace

/* This is the routine manual task, the combination of 
4.C.3.d.3 Pace determined by speed of equipment
4.A.3.a.3 Controlling machines and processes
4.C.2.d.1.i Spend time making repetitive motions
*/
insheet using "onet_15/Work Context.txt", clear
keep if elementid=="4.C.3.d.3" | elementid=="4.C.2.1.i"
keep if scaleid=="CX"
replace datav=(datav-1)*25*2/3 
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_rm1
merge 1:1 onetsoc using acemoglu_autor
drop _merge
save acemoglu_autor, replace

insheet using "onet_15/Work Activities.txt", clear
keep if elementid=="4.A.3.a.3" 
keep if scaleid~="LV"
replace datav=(datav-1)*25/3 if scaleid~="LV"
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_rm2
merge 1:1 onetsoc using acemoglu_autor
drop _merge
gen task_rm=task_rm2+task_rm1
drop task_rm1 task_rm2
save acemoglu_autor, replace

/* This is the nonroutine analytic task, the combination of 
4.A.2.a.4 Analyzing data/information 
4.A.2.b.2 Thinking creatively
4.A.4.a.1 Interpreting Information for others 
*/

insheet using "onet_15/Work Activities.txt", clear
keep if elementid=="4.A.2.a.4" | elementid=="4.A.2.b.2" | elementid=="4.A.4.a.1"
keep if scaleid~="LV"
replace datav=(datav-1)*25 if scaleid~="LV"
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_nra
merge 1:1 onetsoc using acemoglu_autor
drop _merge
save acemoglu_autor, replace

/* This is the nonroutine interactive task. 
4.A.4.a.4 Estabilishing and maintaining personal relationships
4.A.4.b.4 Guiding, directing and motivating suboordinates
4.A.4.b.5 Coaching/developing others
*/
insheet using "onet_15/Work Activities.txt", clear
keep if elementid=="4.A.4.a.4" | elementid=="4.A.4.b.4" | elementid=="4.A.4.b.5"
keep if scaleid~="LV"
replace datav=(datav-1)*25 if scaleid~="LV"
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav task_nri
merge 1:1 onetsoc using acemoglu_autor
drop _merge
ren onetsoc soc
save acemoglu_autor, replace

insheet using soc_2000_to_2010_crosswalk.csv, clear
ren v1 soc00
ren v2 title00
ren v3 soc10
ren v4 title10
replace soc00=subinstr(soc00,"-", "", .)
replace soc10=subinstr(soc10,"-", "", .)
destring soc00 soc10, replace force
save soc_2000_to_2010_crosswalk, replace

/* Step 3
Here we compute the offshorability index of Jentsen and Kltezer (2010), then Blinder (2009)
*/
insheet using "onet_15/Work Activities.txt", clear
keep if elementid=="4.A.1.a.1" |  elementid=="4.A.2.a.2"  |  elementid=="4.A.2.a.4"  |  elementid=="4.A.3.b.1" |  elementid=="4.A.3.b.6" |  elementid=="4.A.4.a.4" |  elementid=="4.A.4.a.5" |  elementid=="4.A.4.a.8"   |  elementid=="4.A.2.b.1" |  elementid=="4.A.2.b.2" |  elementid=="4.A.1.b.2"  
replace datav=datav*100/7*1/2 if scaleid=="LV"
replace datav=(datav-1)*25*3/2 if scaleid~="LV"
replace datav=100-datav if elementid=="4.A.4.a.4" |  elementid=="4.A.4.a.5" |  elementid=="4.A.4.a.8"   |  elementid=="4.A.2.b.1" |  elementid=="4.A.2.b.2" |  elementid=="4.A.1.b.2"  
replace onetsoc=substr(onetsoc,1,7)
replace onetsoc=subinstr(onetsoc,"-", "", .)
destring onetsoc, replace force
collapse (mean) datav, by(onetsoc)
ren datav jentsen
ren onetsoc soc
save jentsen, replace

/* This dataset -- blinder.csv -- comes from the final pages of 
  http://www.princeton.edu/~ceps/workingpapers/142blinder.pdf 
*/

insheet using blinder.csv, clear
ren soc soc00
joinby soc00 using soc_2000_to_2010_crosswalk, unmatched(both)
/* Blinder's dataset used the 2000 version of SOC codes. So that we can merge to 
   the other datasets used in this paper, we need to apply the crosswalk to state 
   things in terms of the 2010 version of SOC codes. */
collapse (mean) score rank, by(soc10)
ren soc10 soc
save blinder_10, replace 

use jentsen, replace
merge 1:1 soc using acemoglu_autor
drop _merge
save onet_elements, replace

/* Step 4: Read in data from BLS Projections */

insheet using bls_2000_2010_projec.csv, clear
replace title=lower(title)
replace title=substr(title, 11,.)+", all other" if strmatch(title, "all other*") 
replace title=subinstr(title,"all other", "other", 1)
replace title=subinstr(title, "-", " ", .)
save bls_projec_early, replace 

/* This file comes from https://www.bls.gov/soc/2000/home.htm */
insheet using soc-structure-2000.csv, clear
ren v1 soc
ren v2 title
replace title=lower(title)
replace title=subinstr(title,"all other", "other", 1)
replace title=subinstr(title, "-", " ", .)
joinby title using bls_projec_early, unmatched(both)
keep if _merge==3
drop _merge job_openings
ren  emp_10 emp_proj_2010
replace soc=subinstr(soc,"-", "", .)
destring soc, replace force
ren soc occsoc
save bls_2000_2010, replace
 
insheet using soc2018_to_soc_corresp.csv, clear 
ren v1 soc2018 
ren v2 soc
drop if _n==1
replace soc=subinstr(soc,"-", "", .)
replace soc2018=subinstr(soc2018,"-", "", .)
save soc2018_to_soc_corresp, replace

insheet using bls_2019_2029_projec.csv, clear
replace soc2018=subinstr(soc2018,"-", "", .)
merge 1:n soc2018 using soc2018_to_soc_corresp
collapse (sum) emp*, by(soc)
ren emp2029 emp_proj_2029
destring soc , replace force 
ren soc occsoc
save bls_2019_2029, replace

/* From 
http://web.archive.org/web/20120202073200/https://www.bls.gov/emp/ep_table_102.htm */
insheet using bls_2010_2020_projec.csv, clear
ren v1 title
ren v2 soc
ren v3 emp2010
drop if _n==1
ren v4 emp_proj_2020
replace soc=subinstr(soc,"-", "", .)
replace emp2010=subinstr(emp2010, ",","",.)
replace emp_proj_2020=subinstr(emp_proj_2020, ",","",.)
destring soc emp*, replace force
ren soc occsoc
save bls_2010_2020, replace
merge 1:1 occsoc using bls_2019_2029 
drop _merge
save bls_projections, replace

use  bls_2000_2010, replace
ren occsoc soc00
merge 1:n soc00 using soc_2000_to_2010_crosswalk
keep if _merge==3
collapse (sum) emp_00 emp_proj_2010 , by(soc10)
ren soc10 occsoc
ren emp_00 emp2000
save bls_projections_early_with_soc_00, replace

/* Step 5: This dataset comes from the appendix Table of Frey and Osborne (2017).
  Merge in datasets from previous steps. */
insheet using frey.csv, clear
replace soc=subinstr(soc,"-", "", .)
destring soc, replace force
gen occsoc=soc
merge 1:1 soc using onet_elements
drop if _merge==2
drop _merge
merge 1:1 soc using blinder_10
ren score blinder_score
replace blinder_score=12 if blinder_score==.
drop _merge
replace occsoc=soc if occsoc==.
merge n:1 occsoc using  bls_2010_2020, keep(2 3)
drop _merge
merge n:1 occsoc using  bls_2019_2029, keep(1 3)
drop _merge
save frey, replace

/* Step 6: Produce right panel of Figure 4. This exercise relies on employment  
    data from 2000 and 2010 and BLS projections between 2000 and 2010 */

use oes_00_10, replace
merge 1:1 occsoc using bls_projections_early_with_soc_00
gen four=floor(occsoc/100)
bys four: egen size=sum(emp_00)
foreach var of varlist emp_proj_2010 emp2000 emp_00 emp_10 {
   sum `var'
   replace `var'=`var'/r(sum)
}
gen bls_proj=log( emp_proj_2010 /emp2000)
gen grow_early=log( emp_10/ emp_00)

collapse  (mean) grow bls_proj size [aw=emp_00], by(four)

graph twoway (scatter grow_early bls_proj, msym(Oh) msize(small)) (scatter grow_early bls_proj if floor(four/100)==43, msym(O) mcolor(red) msize(small)) (scatter grow_early bls_proj if  floor(four/100)==31, msym(O) mcolor(purple) msize(small))  (scatter grow_early bls_proj if floor(four/100)==29, msym(O) mcolor(black) msize(small)) (scatter grow_early bls_proj if floor(four/100)==13, msym(O) mcolor(orange) msize(small)) (scatter grow_early bls_proj if floor(four/100)==51, msym(O) mcolor(blue) msize(small))   , xtitle("BLS Projection: 2000-2010") ytitle("Realized Growth Rate: 2000-2010") legend(off) ylab(-.8(.4).4) ysca(r(-1 .5)) xsca(r(-.5 .3))
graph save fig4b.gph, replace
graph export fig4b.eps, replace

/* This is Appendix: Regression Results, Column 2*/
reg grow_early bls_proj
ren grow_early fig4b_vertical
ren bls_proj fig4b_horizontal
keep four fig4b*
/* this last dataset will be referenced in step 8. */
save to_merge_figures, replace  

/* Step 7: Produce the remaining figures and tables */

use oes_10_19, replace
merge 1:1 occsoc using frey
gen four=floor(occsoc/100)

foreach var of varlist emp_proj_2020 emp2010 emp_19 emp_10  emp_proj_2029 emp2019 {
   sum `var' if prob~=. & emp_proj_2020~=.
   replace `var'=`var'/r(sum)
}

gen bls_proj=log( emp_proj_2020 /emp2010)
gen bls_proj_=log( emp_proj_2029 /emp2019)
gen grow=log( emp_19/ emp_10)
gen task=-(task_nra+task_nri+task_nrm-task_rm-task_rc)
bys four: egen size=sum(emp_10*(prob~=. & emp_proj_2020~=.))
bys four: egen size19=sum(emp2019*(prob~=. & emp_proj_2020~=.))
bys four: egen numer=sum(bls_proj_*emp2019*(prob~=. & emp_proj_2020~=.))
gen bls_proj_future=numer/size19
drop bls_proj_ numer 
collapse  (mean) prob blinder jentsen task grow bls_proj* size* [aw=emp_10], by(four)

cor blinder jentsen
gen comb=blinder/2+jentsen/2
/* This is Table 1 */
cor prob comb task bls_proj

/* Code in the industry names that will go in the figures */
gen ml1=""
gen ml1b=""
replace ml1="Home Health and" if four==3110
replace ml1b="Personal Care Aides" if four==3110
replace ml1="Occupational/Physical" if four==3120
replace ml1b="Therapy Aides" if four==3120
replace ml1="Textile, Apparel," if four==5160
replace ml1b="and Furnishings" if four==5160

replace ml1="Communications" if four==4320
replace ml1b="Equipment Operators" if four==4320
replace ml1="Statistical" if four==4391
replace ml1b="Assistants" if four==4391
replace ml1="Mathematical" if four==1520
replace ml1b="Science" if four==1520

graph twoway (scatter grow bls_proj if ml1=="", msym(Oh) msize(small)) (scatter grow bls_proj if ml1=="" & floor(four/100)==43, msym(O) mcolor(red) msize(small)) (scatter grow bls_proj if ml1=="" & floor(four/100)==31, msym(O) mcolor(purple) msize(small))  (scatter grow bls_proj if ml1=="" & floor(four/100)==29, msym(O) mcolor(black) msize(small)) (scatter grow bls_proj if ml1=="" & floor(four/100)==13, msym(O) mcolor(orange) msize(small)) (scatter grow bls_proj if ml1=="" & floor(four/100)==51, msym(O) mcolor(blue) msize(small))  (scatter grow bls_proj if ml1~="", mlab(ml1) mlabcolor(green) msym(i) mlabsize(vsmall) mlabpos(0)) (scatter grow bls_proj if ml1b~="", mlab(ml1b) mlabcolor(green) msym(i) mlabsize(vsmall) mlabpos(6)) (lfit grow bls_proj, lcolor(black)) (scatter grow bls_proj if ml1b~="" & floor(four/100)==31, mlab(ml1b) mlabc(purple) msym(i) mlabsize(vsmall) mlabpos(6))  (scatter grow bls_proj if ml1b~="" & floor(four/100)==51, mlab(ml1b) mlabc(blue) msym(i) mlabsize(vsmall) mlabpos(6))  (scatter grow bls_proj if ml1b~="" & floor(four/100)==13, mlab(ml1b) mlabc(orange) msym(i) mlabsize(vsmall) mlabpos(6))  (scatter grow bls_proj if ml1b~="" & floor(four/100)==43, mlab(ml1b) mlabc(red) msym(i) mlabsize(vsmall) mlabpos(6))   (scatter grow bls_proj if ml1~="" & floor(four/100)==31, mlab(ml1) mlabc(purple) msym(i) mlabsize(vsmall) mlabpos(0))  (scatter grow bls_proj if ml1~="" & floor(four/100)==51, mlab(ml1) mlabc(blue) msym(i) mlabsize(vsmall) mlabpos(0))  (scatter grow bls_proj if ml1~="" & floor(four/100)==13, mlab(ml1) mlabc(orange) msym(i) mlabsize(vsmall) mlabpos(0))  (scatter grow bls_proj if ml1~="" & floor(four/100)==43, mlab(ml1) mlabc(red) msym(i) mlabsize(vsmall) mlabpos(0))  , xtitle("BLS Projection: 2010-2020") ytitle("Realized Growth Rate: 2010-2019") legend(off) ylab(-.8(.4).4) ysca(r(-1 .5)) xsca(r(-.5 .3))
graph save fig4a.gph, replace
graph export fig4a.eps, replace

graph twoway (scatter grow bls_proj , msym(Oh) msize(small)) (scatter grow bls_proj if floor(four/100)==43, msym(O) mcolor(red) msize(small)) (scatter grow bls_proj if floor(four/100)==31, msym(O) mcolor(purple) msize(small))  (scatter grow bls_proj if floor(four/100)==29, msym(O) mcolor(black) msize(small)) (scatter grow bls_proj if floor(four/100)==13, msym(O) mcolor(orange) msize(small)) (scatter grow bls_proj if floor(four/100)==51, msym(O) mcolor(blue) msize(small))  (lfit grow bls_proj, lcolor(black))  , xtitle("BLS Projection: 2010-2020") ytitle("Realized Growth Rate: 2010-2019") legend(off) ylab(-.8(.4).4) ysca(r(-1 .5)) xsca(r(-.5 .3))
graph export fig4a_notext.eps, replace

graph twoway (scatter grow probability, msym(Oh) msize(small))   (lfit grow probability, lcolor(black)) (scatter grow probability if  floor(four/100)==43, msym(O) mcolor(red) msize(small)) (scatter grow probability if  floor(four/100)==31, msym(O) mcolor(purple) msize(small))  (scatter grow probability if floor(four/100)==29, msym(O) mcolor(black) msize(small)) (scatter grow probability if  floor(four/100)==13, msym(O) mcolor(orange) msize(small)) (scatter grow probability if floor(four/100)==51, msym(O) mcolor(blue) msize(small)) , xtitle("Automation Index: Frey & Osborne") ytitle("Realized Growth Rate: 2010-2019") legend(off) ylab(-.6(.3).6) 
graph save fig5a.gph, replace
graph export fig5a.eps, replace

graph twoway (scatter grow comb, msym(Oh) msize(small))  (lfit grow comb, lcolor(black)) (scatter grow comb if  floor(four/100)==43, msym(O) mcolor(red) msize(small)) (scatter grow comb if  floor(four/100)==31, msym(O) mcolor(purple) msize(small))  (scatter grow comb if floor(four/100)==29, msym(O) mcolor(black) msize(small)) (scatter grow comb if  floor(four/100)==13, msym(O) mcolor(orange) msize(small)) (scatter grow comb if floor(four/100)==51, msym(O) mcolor(blue) msize(small)) , xtitle("Offshorability Index: 1/2 Blinder" "+ 1/2 Jentsen & Kletzer ") ytitle("Realized Growth Rate: 2010-2019") legend(off) ylab(-.6(.3).6) 
graph save fig5b.gph, replace
graph export fig5b.eps, replace
graph twoway (scatter probability bls_proj, msym(Oh) msize(small)) (lfit probability bls_proj , lcolor(black))   , ytitle("Automation Index: Frey & Osborne") xtitle("BLS Projected Growth Rate") legend(off)
graph save fig6a.gph, replace
graph export fig6a.eps, replace


reg probab bls_proj
predict ss1, resid

reg grow bls_proj
predict ss2, resid

graph twoway (scatter ss2 ss1, msym(Oh) msize(small))  (lfit ss2 ss1, lcolor(black)) , xtitle("Automation Index: Frey & Osborne" "(Residual from Regression on BLS Projection)") ytitle("Realized Growth Rate: 2010-2019" "(Residual from Regression on BLS Projection)") legend(off) 
graph save fig6b.gph, replace
graph export fig6b.eps, replace
forvalues x=4/6 {
	graph combine fig`x'a.gph fig`x'b.gph, fysize(70)
	graph export fig`x'.eps, replace 
	graph export fig`x'.tif, replace width(1600) height(1200)
}

reg grow bls_proj probab
* Future projection, last column in figure 7
gen future_projection= 10/9*( _b[_cons]+bls_proj_future*_b[bls_proj]+ _b[probab]*probab)
gen in_sample=(future_projection~=. & size19>.002)
format size19 %13.3f
format probability bls_proj_future* future_projection* size %13.2f

/* These lists are the values for figure 7, columns 1-2 */
gsort -in_sample bls_proj_future
list size19 four probabilit future_projection bls_proj_future if _n<=5, clean noo
gsort -in_sample -bls_proj_future
list size19 four probabilit future_projection bls_proj_future if _n<=5, clean noo


/* This is Appendix: Regression Results with the exception of column 2*/
reg grow bls_proj         // (1)
reg grow probab           // (3)
reg grow comb             // (4)
reg grow bls_proj probab  // (5)

/* Step 8: Combine the variables used in each of the plots */
keep grow comb probability bls_proj ss2 ss1 four
ren ss2 fig6b_vertical
ren ss1 fig6b_horizontal
ren comb fig5b_horizontal
gen fig5b_vertical = grow
gen fig4a_horizontal = bls_proj
gen fig5a_horizontal = probability
ren probability fig6a_vertical
ren bls_proj fig6a_horizontal
ren grow fig4a_vertical
gen fig5a_vertical=fig4a_vertical
merge 1:1 four using to_merge_figures
sort four
drop _merge
ren four occupation
aorder
outsheet using figures_csv.csv, delim(,) replace 

/* Step 9: Produce figures 1-3 */

freduse B021RE1A156NBEA B020RE1A156NBEA  , clear
keep if year(daten)>=1960
gen year=_n+1959
line B020RE1A156NBEA  B021RE1A156NBEA year , xtitle("Year") ytitle("") legend(lab(1 "Exports/GDP") lab(2 "Imports/GDP") r(1)  region(lstyle(none))) ylab(0(5)20) lpattern(solid dash)
graph export fig3.eps, replace 
graph export fig3.tif, replace width(1600) height(1200)
ren B020RE1A156NBEA exports_to_gdp
ren B021RE1A156NBEA imports_to_gdp
outsheet using ei_fig3.csv,  replace delim(,)
 
freduse A679RC1Q027SBEA DPCERD3Q086SBEA, clear
gen real_investment= A679RC1Q027SBEA/DPCERD3Q086SBEA*109.722
keep if month(daten)==4 & year(daten)>=1960 
gen year=_n+1959
line real_inv year , xtitle("Year") ytitle("Information Processing Investment") legend(off) 
graph export fig2.eps, replace 
graph export fig2.tif, replace width(1600) height(1200)
keep real_investment year
outsheet using ei_fig2.csv, replace delim(,)

local list1= "0 1 2 3 4 5 6 7 8 9"
foreach x of local list1 {
	qui {
	insheet using oes_0`x'.csv, clear
	if `x'==6  | `x'==5 {
	   drop if _n==1
	   ren v1 occ_code
	   ren v2 occ_title
	   ren v3 occ_group
	   ren v4 emp_0`x'
	   destring emp_0`x', replace force
	}
	sum emp if occ_code=="00-0000"
	gen share_0`x'=emp/r(mean)
	drop if occ_code=="00-0000"
	keep if substr(occ_code,4,4)=="0000"
	}
	keep occ_code emp share
	save oes_0`x'_fig_1, replace
}
local list2= "0 1 2 3 4 5 6 7 8 9"
foreach x of local list2 {
	insheet using oes_1`x'.csv, clear
	qui {
	sum emp if occ_code=="00-0000"
	gen share_1`x'=emp/r(mean)
	drop if occ_code=="00-0000"
	keep if substr(occ_code,4,4)=="0000"
	if `x'==7 | `x'==8  | `x'==9 {
	  sort occ_code
	  by occ_code: keep if _n==1
	}
	}
	keep occ_code emp share
	save oes_1`x'_fig_1, replace
}
use oes_00_fig_1, replace
forvalues x=1/9 {
	merge 1:1 occ_code using oes_0`x'_fig_1
	drop _merge
}
forvalues x=0/9 {
	merge 1:1 occ_code using oes_1`x'_fig_1
	drop _merge
}

reshape long emp share, i(occ_code) j(year) string
replace year=subinstr(year,"_", "",.)
destring year, replace
replace year=year+2000
sort year
replace emp=emp/1e6
sort occ_code year

/* Here we try to undo the changes in broad occupations' employment shares that are 
 due solely to shifts in the coding scheme. The BLS changed the way it classifies 
 in 2010 and 2019. Here, I regress -- separately for each occupation -- occupations'
 employment shares, with dummies for these separate coding schemes and a flexible
 time trend. The plots in figure 1 are of the estimated time trends.
 
 Note that this issue does not manifest in Figures 4-6, since those exercises are 
 built from detailed 6-digit codes which are present at the two endpoints of each 
 decade. 
*/

gen first=(year<=2009)
gen second=(year>=2019)
gen share_impute=.
gen yearI=year-2010
gen yearI2=yearI^2
gen yearI3=yearI^3
gen yearI4=yearI^4
forvalues x=11(2)53 {
	reg share  yearI yearI2 yearI3 yearI4  i.first i.second if occ_code=="`x'-0000" 
	replace share_impute=_b[_cons]+yearI*_b[yearI]+yearI2*_b[yearI2]+yearI3*_b[yearI3]+yearI4*_b[yearI4] if occ_code=="`x'-0000"
}

graph twoway (line share_impute year if occ_code=="13-0000" )  (line share_impute year if occ_code=="15-0000" , lpattern(dash)) (line share_impute year if occ_code=="43-0000" , lpattern(dot) lwidth(thick))  (line share_impute year if occ_code=="51-0000" , lpattern(longdash) lwidth(medthick)) , ytitle("Employment (Share of Total)") xtitle("Year") legend(lab(1 "Business and Financial") lab(2 "Computer and Math") lab(3 "Administrative Support") lab(4 "Production") region(lwidth(none)))  ylab(0(.04).16)  xlab(2000(4)2016)
graph export fig1.eps, replace 
graph export fig1.tif, replace width(1600) height(1200)
keep share_impute year occ_code
outsheet using ei_fig1.csv, replace delim(,)
